%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Handout painting code. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;
close all;

% Read image and convert it to double, and scale each R,G,B 
% channel to range [0,1].
imRGB = double(imread('orchid.jpg'))/255;
figure(1); clf; imagesc(imRGB); axis equal; axis off;
pause(0.1);

szIm = size(imRGB); szIm = szIm(1:2);

% Set radius of paint brush and half length of drawn lines
rad = 4;
halfLen = 10;

% Set up x, y coordinate images, and canvas.
[x y] = meshgrid(1:szIm(2), 1:szIm(1));
canvas = zeros([szIm, 3]);
canvas(:) = -1; %% Initially mark the canvas with a value out of range.
%% Negative values will be used to denote pixels which are unpainted.

% Random number seed
rand('seed', 29645);

% Orientation of paint brush strokes
theta = 2*pi * rand(1,1);

tic;
for k = 1:500
  
  % Randomly select stroke center
  cntr = floor(rand(2,1) .* [szIm(2); szIm(1)])+1;
  cntr = min(cntr, [szIm(2); szIm(1)]);
  
  % Grab colour from image at center position of the stroke.
  c = reshape(imRGB(cntr(2), cntr(1), :),3,1);
  
  % Set vector from center to one end of the stroke.
  delta = [cos(theta); sin(theta)] * halfLen;
  
  % Add the stroke to the canvas
  canvas = paintStroke(canvas, x, y, cntr-delta, cntr+delta, c, rad);
  
end
toc;

figure(2); clf; 
imagesc(max(canvas,0)); axis equal; axis off;
